@@ -26,6 +26,8 @@ def tidy(
     for msg in box.fetch(bulk=True):
         msg.associated_folder = folder
         apply_list(state.rules, box, msg, dry_run)
+        for script in state.scripts:
+            script.apply(msg, dry_run=dry_run)
         counter += 1
     print()
     print(f"{counter} messages parsed.")
