@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import List, Optional, Union
 
 from imap_tools import BaseMailBox, MailMessage
 from pydantic import Field
@@ -6,9 +6,11 @@ from pydantic import Field
 from .action import Action, MoveAction
 from .common import BaseModel
 from .condition import Condition
+from .sieve import to_sieve_conditions
 
 
 class Rule(BaseModel):
+    name: Optional[str]
     condition: Condition
     move_to: Union[str, None]
     keep_evaluating: bool = False
@@ -38,6 +40,28 @@ class Rule(BaseModel):
     def destinations(self):
         return [action.dest for action in self._actions() if action.action == "move"]
 
+    def to_sieve(self):
+        if self.name:
+            name = self.name
+        elif self.move_to:
+            name = self.move_to
+        else:
+            raise Exception("A rule must have a name to be converted to sieve rules")
+        sieve_conditions = to_sieve_conditions(self.condition)
+        sieve_actions = [action.to_sieve() for action in self._actions()]
+        if not self.keep_evaluating:
+            sieve_actions.append("stop")
+        sieve_actions_str = "\n".join(f"  {action};" for action in sieve_actions)
+        return [
+            f"""
+# rule:[{name}_{i}]
+{sieve_condition.dump()}
+{{
+{sieve_actions_str}
+}}"""
+            for i, sieve_condition in enumerate(sieve_conditions)
+        ]
+
 
 def apply_list(rules: List[Rule], mailbox: BaseMailBox, message: MailMessage, dry_run: bool):
     for rule in rules:
