@@ -2,6 +2,8 @@ from typing import Optional
 
 from pydantic import BaseSettings
 
+from mmuxer.models.common import BaseModel
+
 
 def in_container():
     """Returns: True iff running in a container"""
@@ -19,7 +21,7 @@ if in_container():
     BaseConfig.secrets_dir = "/run/secrets"
 
 
-class Settings(BaseSettings):
+class Settings(BaseModel, BaseSettings):
     server: str
     username: str
     password: str
